diff mbox series

[1/3] mm/rmap: rename page__anon_vma to page_anon_vma for consistency

Message ID 20250418075226.695014-2-ye.liu@linux.dev (mailing list archive)
State New
Headers show
Series mm: minor cleanups in rmap and memory-failure | expand

Commit Message

Ye Liu April 18, 2025, 7:52 a.m. UTC
From: Ye Liu <liuye@kylinos.cn>

Renamed local variable page__anon_vma in page_address_in_vma() to
page_anon_vma. The previous naming convention of using double underscores
(__) is unnecessary and inconsistent with typical kernel style, which uses
single underscores to denote local variables. Also updated comments to
reflect the new variable name.

Functionality unchanged.

Signed-off-by: Ye Liu <liuye@kylinos.cn>
---
 mm/rmap.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

Comments

Lorenzo Stoakes April 18, 2025, 9:14 a.m. UTC | #1
On Fri, Apr 18, 2025 at 03:52:24PM +0800, Ye Liu wrote:
> From: Ye Liu <liuye@kylinos.cn>
>
> Renamed local variable page__anon_vma in page_address_in_vma() to
> page_anon_vma. The previous naming convention of using double underscores
> (__) is unnecessary and inconsistent with typical kernel style, which uses
> single underscores to denote local variables. Also updated comments to
> reflect the new variable name.
>
> Functionality unchanged.
>
> Signed-off-by: Ye Liu <liuye@kylinos.cn>

Thanks, this looks good. I don't know why we named it this way :)

Reviewed-by: Lorenzo Stoakes <lorenzo.stoakes@oracle.com>

> ---
>  mm/rmap.c | 8 ++++----
>  1 file changed, 4 insertions(+), 4 deletions(-)
>
> diff --git a/mm/rmap.c b/mm/rmap.c
> index 67bb273dfb80..b509c226e50d 100644
> --- a/mm/rmap.c
> +++ b/mm/rmap.c
> @@ -789,13 +789,13 @@ unsigned long page_address_in_vma(const struct folio *folio,
>  		const struct page *page, const struct vm_area_struct *vma)
>  {
>  	if (folio_test_anon(folio)) {
> -		struct anon_vma *page__anon_vma = folio_anon_vma(folio);
> +		struct anon_vma *page_anon_vma = folio_anon_vma(folio);
>  		/*
>  		 * Note: swapoff's unuse_vma() is more efficient with this
>  		 * check, and needs it to match anon_vma when KSM is active.
>  		 */
> -		if (!vma->anon_vma || !page__anon_vma ||
> -		    vma->anon_vma->root != page__anon_vma->root)
> +		if (!vma->anon_vma || !page_anon_vma ||
> +		    vma->anon_vma->root != page_anon_vma->root)
>  			return -EFAULT;
>  	} else if (!vma->vm_file) {
>  		return -EFAULT;
> @@ -803,7 +803,7 @@ unsigned long page_address_in_vma(const struct folio *folio,
>  		return -EFAULT;
>  	}
>
> -	/* KSM folios don't reach here because of the !page__anon_vma check */
> +	/* KSM folios don't reach here because of the !page_anon_vma check */
>  	return vma_address(vma, page_pgoff(folio, page), 1);
>  }
>
> --
> 2.25.1
>
Harry Yoo April 18, 2025, 9:37 a.m. UTC | #2
On Fri, Apr 18, 2025 at 10:14:25AM +0100, Lorenzo Stoakes wrote:
> On Fri, Apr 18, 2025 at 03:52:24PM +0800, Ye Liu wrote:
> > From: Ye Liu <liuye@kylinos.cn>
> >
> > Renamed local variable page__anon_vma in page_address_in_vma() to
> > page_anon_vma. The previous naming convention of using double underscores
> > (__) is unnecessary and inconsistent with typical kernel style, which uses
> > single underscores to denote local variables. Also updated comments to
> > reflect the new variable name.
> >
> > Functionality unchanged.
> >
> > Signed-off-by: Ye Liu <liuye@kylinos.cn>
> 
> Thanks, this looks good. I don't know why we named it this way :)

At that time there was page_anon_vma() instead of folio_anon_vma()
so the author couldn't name the variable page_anon_vma :)
Lorenzo Stoakes April 18, 2025, 9:42 a.m. UTC | #3
On Fri, Apr 18, 2025 at 06:37:58PM +0900, Harry Yoo wrote:
> On Fri, Apr 18, 2025 at 10:14:25AM +0100, Lorenzo Stoakes wrote:
> > On Fri, Apr 18, 2025 at 03:52:24PM +0800, Ye Liu wrote:
> > > From: Ye Liu <liuye@kylinos.cn>
> > >
> > > Renamed local variable page__anon_vma in page_address_in_vma() to
> > > page_anon_vma. The previous naming convention of using double underscores
> > > (__) is unnecessary and inconsistent with typical kernel style, which uses
> > > single underscores to denote local variables. Also updated comments to
> > > reflect the new variable name.
> > >
> > > Functionality unchanged.
> > >
> > > Signed-off-by: Ye Liu <liuye@kylinos.cn>
> >
> > Thanks, this looks good. I don't know why we named it this way :)
>
> At that time there was page_anon_vma() instead of folio_anon_vma()
> so the author couldn't name the variable page_anon_vma :)

Ahhh mystery__solved! Thanks Harry ;)

>
> --
> Cheers,
> Harry / Hyeonggon
>
> > Reviewed-by: Lorenzo Stoakes <lorenzo.stoakes@oracle.com>
> >
> > > ---
> > >  mm/rmap.c | 8 ++++----
> > >  1 file changed, 4 insertions(+), 4 deletions(-)
> > >
> > > diff --git a/mm/rmap.c b/mm/rmap.c
> > > index 67bb273dfb80..b509c226e50d 100644
> > > --- a/mm/rmap.c
> > > +++ b/mm/rmap.c
> > > @@ -789,13 +789,13 @@ unsigned long page_address_in_vma(const struct folio *folio,
> > >  		const struct page *page, const struct vm_area_struct *vma)
> > >  {
> > >  	if (folio_test_anon(folio)) {
> > > -		struct anon_vma *page__anon_vma = folio_anon_vma(folio);
> > > +		struct anon_vma *page_anon_vma = folio_anon_vma(folio);
> > >  		/*
> > >  		 * Note: swapoff's unuse_vma() is more efficient with this
> > >  		 * check, and needs it to match anon_vma when KSM is active.
> > >  		 */
> > > -		if (!vma->anon_vma || !page__anon_vma ||
> > > -		    vma->anon_vma->root != page__anon_vma->root)
> > > +		if (!vma->anon_vma || !page_anon_vma ||
> > > +		    vma->anon_vma->root != page_anon_vma->root)
> > >  			return -EFAULT;
> > >  	} else if (!vma->vm_file) {
> > >  		return -EFAULT;
> > > @@ -803,7 +803,7 @@ unsigned long page_address_in_vma(const struct folio *folio,
> > >  		return -EFAULT;
> > >  	}
> > >
> > > -	/* KSM folios don't reach here because of the !page__anon_vma check */
> > > +	/* KSM folios don't reach here because of the !page_anon_vma check */
> > >  	return vma_address(vma, page_pgoff(folio, page), 1);
> > >  }
> > >
> > > --
> > > 2.25.1
> > >
diff mbox series

Patch

diff --git a/mm/rmap.c b/mm/rmap.c
index 67bb273dfb80..b509c226e50d 100644
--- a/mm/rmap.c
+++ b/mm/rmap.c
@@ -789,13 +789,13 @@  unsigned long page_address_in_vma(const struct folio *folio,
 		const struct page *page, const struct vm_area_struct *vma)
 {
 	if (folio_test_anon(folio)) {
-		struct anon_vma *page__anon_vma = folio_anon_vma(folio);
+		struct anon_vma *page_anon_vma = folio_anon_vma(folio);
 		/*
 		 * Note: swapoff's unuse_vma() is more efficient with this
 		 * check, and needs it to match anon_vma when KSM is active.
 		 */
-		if (!vma->anon_vma || !page__anon_vma ||
-		    vma->anon_vma->root != page__anon_vma->root)
+		if (!vma->anon_vma || !page_anon_vma ||
+		    vma->anon_vma->root != page_anon_vma->root)
 			return -EFAULT;
 	} else if (!vma->vm_file) {
 		return -EFAULT;
@@ -803,7 +803,7 @@  unsigned long page_address_in_vma(const struct folio *folio,
 		return -EFAULT;
 	}
 
 	/* KSM folios don't reach here because of the !page__anon_vma check */
 	return vma_address(vma, page_pgoff(folio, page), 1);
 }
@@ -803,7 +803,7 @@  unsigned long page_address_in_vma(const struct folio *folio,
 	}
 
-	/* KSM folios don't reach here because of the !page__anon_vma check */
+	/* KSM folios don't reach here because of the !page_anon_vma check */
 	return vma_address(vma, page_pgoff(folio, page), 1);
 }